@@ -1,7 +1,7 @@
 pub struct Multifactorials;
 
 impl Multifactorials {
-    fn from(mut n: i128, factorials: i32) -> i128 {
+    pub fn from(mut n: i128, factorials: i32) -> i128 {
         let mut res = vec![];
 
         if n < 3 {
@@ -15,8 +15,6 @@ impl Multifactorials {
                 res.push(n);
 
                 n = n - factorials as i128;
-
-                println!("{}", n)
             }
         }
 
